#include  "Device_430.h"
#include "spi.h"

/* Initialize and enable the SPI module */
void spi_initialize( )
{
	SPI_PORT_SEL = SPI_PINS_SEL; // Setup Px for SPI mode
	SS_PORT_DIR|= SS_PIN; // Setup the SS as output
	// low. So, initialize it high.
	SS_PORT_OUT|= SS_PIN; // Set SS High
	
	SD_UCTL= (CHAR | SYNC | MM | SWRST); // 8-bit, SPI, Master
	SD_UTCTL= (SSEL1 | STC | CKPH); // Normal polarity, 3-wire
	SD_UBR0= 0x002; // SPICLK = SMCLK/2 (2=Minimum divisor)
	SD_UBR1= 0x000;
	SD_UMCTL= 0x000;
	SD_MOD_REG|= SD_USPIE; // Module enable
	SD_UCTL&= ~SWRST; // SPI enable
}

/* Set the baud-rate divisor. The correct value is computed by dividing
the clock rate by the desired baud rate. The minimum divisor allowed
is 2. */
void spi_set_divisor( WORD divisor )
{
	SD_UCTL|= SWRST; // Temporarily disable the SPI module
	SD_UBR1= divisor >> 8;
	SD_UBR0= divisor;
	SD_UCTL&= ~SWRST; // Re-enable SPI
}

/* Send a single byte over the SPI port */
void spi_send_byte( BYTE input )
{
	SPI_IFG&= ~SD_UTXIFG;
	/* Send the byte */
	SD_UTXBUF= input;
	/* Wait for the byte to be sent */
	while ( ! ( SPI_IFG & SD_UTXIFG ) )
		;
}

/* Receive a byte. Output an 0xFF (the bus idles high) to receive the byte */
BYTE spi_rcv_byte( )
{
	unsigned char tmp;
	SPI_IFG&= ~SD_URXIFG;
	
	/* Send the byte */
	SD_UTXBUF= 0xFF;
	
	/* Wait for the byte to be received */
	while( ! ( SPI_IFG & SD_URXIFG ) )
		;
	tmp= SD_URXBUF;
	return tmp;
}

